@@ -1,10 +1,9 @@
-from chalice import Response
+from chalice import Response, Chalice, Blueprint
 import hashlib
 import pickle
 from jinja2 import meta, FileSystemLoader
 from chalice_http_toolkit.content import ContentManager
-from typing import Optional, Callable
-from chalice import Chalice
+from typing import Optional, Callable, Union
 from datetime import datetime
 import traceback
 import os
@@ -18,7 +17,7 @@ class CloudFront:
     :param content_manager: challice_http_toolkit.ContentManager
     :returns: CloudFront instance
     """
-    def __init__(self, content_manager:ContentManager, app:Chalice):
+    def __init__(self, content_manager:ContentManager, app:Union[Chalice, Blueprint]):
         self.__fsl = FileSystemLoader(content_manager.templates_dir)
         self.__cm = content_manager
         self.__app = app
