@@ -2,12 +2,12 @@ import jinja2
 import os
 import io
 import base64
-from typing import Optional
-from chalice import Response, Chalice
+from typing import Optional, Union
+from chalice import Response, Chalice, Blueprint
 from magic import Magic
 from chalice_http_toolkit.response_with_binary import ResponseWithBinary
 import json
-from PIL import Image
+from PIL import Image, UnidentifiedImageError
 
 class ContentManager:
     """
@@ -21,10 +21,18 @@ class ContentManager:
     :param magic: Optional python-magic instance, often required given Lambda hosts dont have libmagic installed.
     :returns: ContentManager instance
     """
-    def __init__(self, templates_dir:str, static_dir:str, app:Chalice, magic:Optional[Magic]=None):
+    def __init__(self, templates_dir:str, static_dir:str, app:Union[Chalice, Blueprint], magic:Optional[Magic]=None):
         self.templates_dir = templates_dir
         self.static_dir = static_dir
-        self.__allowed_static_files = os.listdir(static_dir)
+        self.__allowed_static_files = []
+        dirlist = [static_dir]
+        while len(dirlist) > 0:
+            for (dirpath, dirnames, filenames) in os.walk(dirlist.pop()):
+                dirlist.extend(dirnames)
+                for fn in filenames:
+                    p = os.path.join(dirpath, fn)
+                    p = os.path.relpath(p, static_dir)
+                    self.__allowed_static_files.append(p)
         self.env = jinja2.Environment(loader=jinja2.FileSystemLoader(templates_dir))
         self.__magic = magic if magic else Magic(mime=True)
         self.__app = app
@@ -74,7 +82,10 @@ class ContentManager:
         else:
             if default is None:
                 raise Exception('Couldnt match accepts with supported formats: %s' % accepts)
-        image = Image.open(io.BytesIO(img))
+        try:
+            image = Image.open(io.BytesIO(img))
+        except UnidentifiedImageError:
+            return img
         with io.BytesIO() as output:
             image.save(output, format=new_format)
             converted = output.getvalue()
@@ -117,7 +128,7 @@ class ContentManager:
             body = f.read()
         if filename.endswith('.css'):
             content_type = 'text/css'
-        elif filename.endswith('.js'):
+        elif filename.endswith('.js') or filename.endswith('.mjs'):
             content_type = 'text/javascript'
         else:
             content_type = self.__magic.from_buffer(body)
@@ -163,13 +174,13 @@ class ContentManager:
             h = {**h, **headers}
         return Response(body=json.dumps(body), status_code=status_code, headers=h)
 
-    def redirect(self, url:str) -> Response:
+    def redirect(self, url:str, status_code:int=301) -> Response:
         """
-        Generates a 301 redirect Response.
+        By default generates a 301 redirect Response.
 
         :param url: URL to redirect to
         :returns: Chalice Response object
         """
-        return Response(status_code=301,
+        return Response(status_code=status_code,
                         body='',
                         headers={'Location': url})
\ No newline at end of file
